@@ -1,6 +1,7 @@
 import os
 import shutil
 from collections import MutableMapping, namedtuple
+import numpy as np
 
 import pathlib
 
@@ -37,4 +38,8 @@ def flatten_dict(dictionary, parent_key='', separator='.'):
         key = parent_key + separator + key if parent_key else key
         if isinstance(value, MutableMapping): items.extend(flatten_dict(value, key, separator).items())
         else: items.append((key, value))
-    return dict(items)
\ No newline at end of file
+    return dict(items)
+
+
+def ndarray_index_from(collection, array):
+    return [np.array_equal(array, other) for other in collection].index(True)
